//设计目标：同时点亮四个LED灯，闪烁三次；LED0和LED2同时闪烁2次后，LED1和LED3同时闪烁2次；然后逐个点亮四个LED灯，维持1秒钟后四个LED灯逐个熄灭。依次此循环

module mdyBookHuxiLedExec06(
   clk    ,
   rst_n  ,
   led0   ,
   led1   ,
   led2   ,
   led3
);

//定义输入、输出信号
input   clk  ;
input   rst_n;
output  led0 ;
output  led1 ;
output  led2 ;
output  led3 ;

//定义信号类型
reg[25:0]     cnt0    ;
wire          add_cnt0;
wire          end_cnt0;
reg[4:0]      cnt1    ;
wire          add_cnt1;
wire          end_cnt1;
reg           led0    ;
reg           led1    ;
reg           led2    ;
reg           led3    ;

parameter TIME_1S = 50_000_000;

//cnt0:时钟计数器
//加1条件：计数器不停地工作，一直有效
//结束条件：计数50000000（1秒钟）次结束
always @(posedge clk or negedge rst_n)begin
    if(!rst_n)begin
        cnt0 <= 0;
    end
    else if(add_cnt0)begin
        if(end_cnt0)
            cnt0 <= 0;
        else
            cnt0 <= cnt0 + 1;
    end
end

assign add_cnt0 = 1;
assign end_cnt0 = add_cnt0 && cnt0== TIME_1S-1;

//cnt1:秒计数器
//加1条件：end_cnt0
//结束条件：计数23秒结束
always @(posedge clk or negedge rst_n)begin 
    if(!rst_n)begin
        cnt1 <= 0;
    end
    else if(add_cnt1)begin
        if(end_cnt1)
            cnt1 <= 0;
        else
            cnt1 <= cnt1 + 1;
    end
end

assign add_cnt1 = end_cnt0;
assign end_cnt1 = add_cnt1 && cnt1== 23-1 ;

//根据设计目的，分析led0在不同时间段的高低电平情况
always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        led0 <= 1;
    end
    else if(add_cnt1 && (cnt1 ==1-1 || cnt1 ==3-1 || cnt1 ==5-1 || cnt1 ==7-1 || cnt1 ==9-1 ||cnt1 ==14-1))begin
        led0 <= 0;
    end
    else if(add_cnt1 && (cnt1 ==2-1 || cnt1 ==4-1 || cnt1 ==6-1 || cnt1 ==8-1 || cnt1 ==10-1 || cnt1 ==19-1))begin
        led0 <= 1;
    end
end

//根据设计目的，分析led1在不同时间段的高低电平情况
always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        led1 <= 1;
    end
    else if(add_cnt1 && (cnt1 ==1-1 || cnt1 ==3-1 || cnt1 ==5-1 || cnt1 ==11-1 || cnt1 ==13-1 || cnt1 ==15-1))begin
        led1 <= 0;
    end
    else if(add_cnt1 && (cnt1 ==2-1 || cnt1 ==4-1 || cnt1 ==6-1 || cnt1 ==12-1 || cnt1 ==14-1 || cnt1 ==20-1))begin
        led1 <= 1;
    end
end

//根据设计目的，分析led2在不同时间段的高低电平情况
always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        led2 <= 1;
    end
    else if(add_cnt1 && (cnt1 ==1-1 || cnt1 ==3-1 || cnt1 ==5-1 || cnt1 ==7-1 
        || cnt1 ==9-1 || cnt1 ==16-1))begin
        led2 <= 0;
    end
    else if(add_cnt1 && (cnt1 ==2-1 || cnt1 ==4-1 || cnt1 ==6-1 || cnt1 ==8-1 || cnt1 ==10-1 || cnt1 ==21-1))begin
        led2 <= 1;
    end
end

//根据设计目的，分析led3在不同时间段的高低电平情况
always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        led3 <= 1;
    end
    else if(add_cnt1 && (cnt1 ==1-1 || cnt1 ==3-1 || cnt1 ==5-1 || cnt1 ==11-1
        || cnt1 ==13-1 || cnt1 ==17-1))begin
        led3 <= 0;
    end
    else if(add_cnt1 && (cnt1 ==2-1 || cnt1 ==4-1 || cnt1 ==6-1 || cnt1 ==12-1 || cnt1 ==14-1 || cnt1 ==22-1))begin
        led3 <= 1;
    end
end

endmodule


